@@ -9,38 +9,38 @@ OC.L10N.register(
     "Completed" : "Lokið",
     "Tasks" : "Verkefni",
     "The Tasks app for Nextcloud" : "Verkefnaforrit fyrir Nextcloud",
-    "Add List…" : "Bæta við lista...",
-    "New List" : "Nýr listi",
-    "Cancel" : "Hætta við",
-    "Save" : "Vista",
-    "An empty name is not allowed." : "Autt heiti er ekki leyft.",
+    "Default list" : "Sjálfgefinn listi",
+    "Visibility of Smart Collections" : "Sýnileiki snjallsafna (Smart Collections)",
+    "Hidden" : "Falið",
+    "Visible" : "Sýnilegt",
+    "Automatic" : "Sjálfvirkt",
     "Share with users or groups" : "Deila með notendum eða hópum",
     "No users or groups" : "Engir notendur eða hópar",
-    "can edit" : "getur breytt",
     "Unshare with {displayName}" : "Hætta deilingu með {displayName}",
     "Unable to delete the share." : "Get ekki eytt sameigninni.",
     "Unable to change permissions." : "Tekst ekki að breyta heimildum.",
     "Edit" : "Breyta",
     "Copy private link" : "Afrita einkatengil",
     "Copied" : "Afritað",
-    "Can not copy" : "Gat ekki afritað",
     "Download" : "Sækja",
     "Delete" : "Eyða",
     "Unshare" : "Hætta deilingu",
+    "Cancel" : "Hætta við",
+    "Save" : "Vista",
     "Calendar link copied to clipboard." : "Dagatalstengill afritaður á klippispjald.",
     "Calendar link could not be copied to clipboard." : "Ekki var hægt að afrita dagatalstengil á klippispjald.",
+    "An empty name is not allowed." : "Autt heiti er ekki leyft.",
     "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["Deilt með {num} einindi","Deilt með {num} einindum"],
-    "Default list" : "Sjálfgefinn listi",
-    "Visibility of Smart Collections" : "Sýnileiki snjallsafna (Smart Collections)",
-    "Hidden" : "Falið",
-    "Visible" : "Sýnilegt",
-    "Automatic" : "Sjálfvirkt",
     "Delete all completed tasks." : "Eyða öllum loknum verkum.",
     "Delete completed tasks." : "Eyða loknum verkum.",
     "No errors" : "Engar villur",
     "Open your browser console for more details" : "Opnaðu stjórnborð vafrans þíns til að sjá frekari upplýsingar",
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Gat ekki eytt {failedCount} verkefni.","Gat ekki eytt {failedCount} verkefnum."],
+    "Add an important task to \"{calendar}\"…" : "Bæta mikilvægu verkefni við \"{calendar}\"...",
+    "Add a task due today to \"{calendar}\"…" : "Bæta verkefni sem á að klára í dag við \"{calendar}\"...",
+    "Add a current task to \"{calendar}\"…" : "Bæta fyrirliggjandi verkefni við \"{calendar}\"...",
+    "Add a task to \"{calendar}\"…" : "Bæta verkefni við \"{calendar}\"...",
     "Load all completed tasks." : "Hlaða inn öllum loknum verkum.",
     "Change sort order" : "Breyta röðun",
     "Sort by completed state, due date, priority, start date and summary." : "Raða eftir framvindustöðu, skiladegi, forgangi, upphafsdagsetningu og yfirliti.",
@@ -67,25 +67,16 @@ OC.L10N.register(
     "[Tomorrow]" : "[Á morgun]",
     "Add a subtask to \"{task}\"…" : "Bæta undirverkefni við \"{task}\"...",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n lokið verkefni","%n lokin verkefni"],
-    "Add an important task to \"{calendar}\"…" : "Bæta mikilvægu verkefni við \"{calendar}\"...",
-    "Add a task due today to \"{calendar}\"…" : "Bæta verkefni sem á að klára í dag við \"{calendar}\"...",
-    "Add a current task to \"{calendar}\"…" : "Bæta fyrirliggjandi verkefni við \"{calendar}\"...",
-    "Add a task to \"{calendar}\"…" : "Bæta verkefni við \"{calendar}\"...",
     "Tomorrow" : "Á morgun",
-    "Set start date" : "Setja upphafsdag",
-    "Set start time" : "Setja upphafstíma",
-    "Set due date" : "Setja skiladag",
-    "Set due time" : "Setja skilatíma",
+    "Add List…" : "Bæta við lista...",
+    "New List" : "Nýr listi",
     "All day" : "Heilsdagsviðburður",
-    "Select a calendar" : "Veldu dagatal",
     "Select a classification" : "Veldu flokkun",
-    "Select categories" : "Veldu flokka",
-    "Add this as a new category" : "Bæta þessu við sem nýjum flokki",
-    "Task not found!" : "Verkefn fannst ekki!",
     "When shared show full event" : "Þegar er deilt, birta allan atburð",
     "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
     "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
     "Canceled" : "Hætt við",
+    "Task not found!" : "Verkefn fannst ekki!",
     "[Starts today]" : "[Byrjar í dag]",
     "[Starts tomorrow]" : "[Byrjar á morgun]",
     "[Starts on] LL" : "[Byrjar þann] LL",
@@ -97,6 +88,7 @@ OC.L10N.register(
     "[Starts on] LL [at] LT" : "[Byrjar þann] LL [klukkan] LT",
     "[Started yesterday at] LT" : "[Byrjaði í gær klukkan] LT",
     "[Started on] LL [at] LT" : "[Byrjaði þann] LL [klukkan] LT",
+    "Set start date" : "Setja upphafsdag",
     "[Due today]" : "[Á að ljúka í dag]",
     "[Due tomorrow]" : "[Á að ljúka á morgun]",
     "[Due on] LL" : "[Á að ljúka þann] LL",
@@ -108,6 +100,7 @@ OC.L10N.register(
     "[Due on] LL [at] LT" : "[Á að ljúka þann] LL [klukkan] LT",
     "[Was due yesterday at] LT" : "[Átti að ljúka í gær klukkan] LT",
     "[Was due on] LL [at] LT" : "[Átti að ljúka þann] LL [klukkan] LT",
+    "Set due date" : "Setja skiladag",
     "No priority assigned" : "Enginn forgangur settur",
     "Could not delete the task." : "Gat ekki eytt verkefninu.",
     "Synchronizing to the server." : "Samstilli við netþjóninn.",
