@@ -8,31 +8,28 @@ OC.L10N.register(
     "Current" : "현재",
     "Completed" : "완료됨",
     "Tasks" : "작업",
-    "Add List…" : "리스트 더하기...",
-    "New List" : "새 목록",
-    "Cancel" : "취소",
-    "Save" : "저장",
-    "An empty name is not allowed." : "이름을 비워둘 수 없습니다.",
-    "Share with users or groups" : "사용자 및 그룹과 공유",
-    "No users or groups" : "사용자나 그룹 없음",
-    "can edit" : "편집 가능",
-    "Unable to delete the share." : "이 공유를 삭제할 수 없습니다.",
-    "Unable to change permissions." : "권한을 변경할 수 없습니다.",
-    "Edit" : "편집",
-    "Copy private link" : "개인 링크 주소 복사",
-    "Copied" : "복사됨",
-    "Can not copy" : "복사할 수 없음",
-    "Download" : "다운로드",
-    "Delete" : "삭제",
-    "Unshare" : "공유 해제",
-    "Calendar link copied to clipboard." : "일정의 링크를 클립보드에 복사되었습니다.",
-    "Calendar link could not be copied to clipboard." : "일정의 링크를 클립보드에 저장할 수 없습니다.",
-    "An error occurred, unable to delete the calendar." : "오류가 발생하여 일정을 삭제할 수 없습니다.",
+    "The Tasks app for Nextcloud" : "Nextcloud 작업 앱",
     "Default list" : "기본 리스트",
     "Visibility of Smart Collections" : "똑똑한 모음집 표시 여부",
     "Hidden" : "숨김",
     "Visible" : "보임",
     "Automatic" : "자동",
+    "Share with users or groups" : "사용자 및 그룹과 공유",
+    "No users or groups" : "사용자나 그룹 없음",
+    "Unable to delete the share." : "이 공유를 삭제할 수 없습니다.",
+    "Unable to change permissions." : "권한을 변경할 수 없습니다.",
+    "Edit" : "편집",
+    "Copy private link" : "개인 링크 주소 복사",
+    "Copied" : "복사됨",
+    "Download" : "다운로드",
+    "Delete" : "삭제",
+    "Unshare" : "공유 해제",
+    "Cancel" : "취소",
+    "Save" : "저장",
+    "Calendar link copied to clipboard." : "일정의 링크를 클립보드에 복사되었습니다.",
+    "Calendar link could not be copied to clipboard." : "일정의 링크를 클립보드에 저장할 수 없습니다.",
+    "An empty name is not allowed." : "이름을 비워둘 수 없습니다.",
+    "An error occurred, unable to delete the calendar." : "오류가 발생하여 일정을 삭제할 수 없습니다.",
     "Delete all completed tasks." : "모든 완료된 일 지우기",
     "Delete completed tasks." : "완료된 일 지우기",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "\"{calendar}\" 달력의 모든 완료된 일 지우기",
@@ -57,14 +54,16 @@ OC.L10N.register(
     "Task is completed" : "작업이 완료됨",
     "_%n Completed Task_::_%n Completed Tasks_" : ["완료된 작업 %n개"],
     "Tomorrow" : "내일",
-    "Set start date" : "시작 날짜 지점",
-    "Set due date" : "만료 기한 설정",
+    "Add List…" : "리스트 더하기...",
+    "New List" : "새 목록",
     "All day" : "하루 종일",
-    "Task not found!" : "작업을 찾을 수 없습니다!",
     "When shared show full event" : "전체 일정 공유",
     "When shared show only busy" : "바쁨/한가함만 공유",
     "When shared hide this event" : "일정 공유하지 않음",
     "Canceled" : "취소됨",
+    "Task not found!" : "작업을 찾을 수 없습니다!",
+    "Set start date" : "시작 날짜 지점",
+    "Set due date" : "만료 기한 설정",
     "An error occurred" : "오류가 발생함"
 },
 "nplurals=1; plural=0;");
