@@ -8,25 +8,22 @@ OC.L10N.register(
     "Current" : "Pašreizējais",
     "Completed" : "Pabeigts",
     "Tasks" : "Uzdevumi",
-    "New List" : "Jauns saraksts",
-    "Cancel" : "Atcelt",
-    "Save" : "Saglabāt",
-    "An empty name is not allowed." : "Nosaukums ir obligāts.",
-    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
-    "No users or groups" : "Nav lietotāji vai grupas",
-    "can edit" : "var rediģēt",
-    "Unable to delete the share." : "Nevar izdzēst kopīgošanu.",
-    "Unable to change permissions." : "Nevar mainīt atļaujas.",
-    "Edit" : "Rediģēt",
-    "Copied" : "Nokopēts",
-    "Can not copy" : "Nevar nokopēt",
-    "Download" : "Lejupielādēt",
-    "Delete" : "Dzēst",
-    "Unshare" : "Pārtraukt dalīšanos",
     "Visibility of Smart Collections" : "Viedo kolekciju redzamība",
     "Hidden" : "Paslēpts",
     "Visible" : "Redzams",
     "Automatic" : "Automātisks",
+    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
+    "No users or groups" : "Nav lietotāji vai grupas",
+    "Unable to delete the share." : "Nevar izdzēst kopīgošanu.",
+    "Unable to change permissions." : "Nevar mainīt atļaujas.",
+    "Edit" : "Rediģēt",
+    "Copied" : "Nokopēts",
+    "Download" : "Lejupielādēt",
+    "Delete" : "Dzēst",
+    "Unshare" : "Pārtraukt dalīšanos",
+    "Cancel" : "Atcelt",
+    "Save" : "Saglabāt",
+    "An empty name is not allowed." : "Nosaukums ir obligāts.",
     "No errors" : "Nav kļūdu",
     "Open your browser console for more details" : "Atveriet savas pārlūkprogrammas konsoli sīkākai informācijai",
     "Change sort order" : "Mainīt kārtošanas secību",
@@ -39,13 +36,14 @@ OC.L10N.register(
     "Task is completed" : "Uzdevums pabeigts",
     "_%n Completed Task_::_%n Completed Tasks_" : ["neviena pabeigta uzdevuma","%n paeigts uzdevums","%n pabeigti uzvedumi"],
     "Tomorrow" : "Rīt",
-    "Set start date" : "Uzstādīt sākuma datumu",
-    "Set due date" : "Uzstādīt izpildes termiņu",
+    "New List" : "Jauns saraksts",
     "All day" : "Visas dienas",
-    "Task not found!" : "Uzdevums nav atrasts!",
     "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
     "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
     "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
+    "Task not found!" : "Uzdevums nav atrasts!",
+    "Set start date" : "Uzstādīt sākuma datumu",
+    "Set due date" : "Uzstādīt izpildes termiņu",
     "An error occurred" : "Gadījās kļūda"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
