@@ -8,37 +8,37 @@ OC.L10N.register(
     "Current" : "Actual",
     "Completed" : "Concluída",
     "Tasks" : "Tarefas",
-    "New List" : "Nova Lista",
-    "Cancel" : "Cancelar",
-    "Save" : "Guardar",
-    "An empty name is not allowed." : "Não é permitido um nome em branco.",
-    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
-    "No users or groups" : "Sem utilizadores ou grupos",
-    "can edit" : "pode editar",
-    "Unable to delete the share." : "Não foi possível eliminar a partilha de rede.",
-    "Unable to change permissions." : "Não é possível alterar as permissões.",
-    "Edit" : "Editar",
-    "Copied" : "Copiado",
-    "Can not copy" : "Não é possível copiar",
-    "Download" : "Transferir",
-    "Delete" : "Eliminar ",
-    "Unshare" : "Cancelar partilha",
     "Visibility of Smart Collections" : "Visibilidade das Coleções Inteligentes",
     "Hidden" : "Escondido",
     "Visible" : "Visível",
     "Automatic" : "Automático",
+    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
+    "No users or groups" : "Sem utilizadores ou grupos",
+    "Unable to delete the share." : "Não foi possível eliminar a partilha de rede.",
+    "Unable to change permissions." : "Não é possível alterar as permissões.",
+    "Edit" : "Editar",
+    "Copied" : "Copiado",
+    "Download" : "Transferir",
+    "Delete" : "Eliminar ",
+    "Unshare" : "Cancelar partilha",
+    "Cancel" : "Cancelar",
+    "Save" : "Guardar",
+    "Calendar link copied to clipboard." : "Link do calendário copiado para a área de transferência.",
+    "An empty name is not allowed." : "Não é permitido um nome em branco.",
     "No errors" : "Sem erros",
     "Open your browser console for more details" : "Abra a consola do seu navegador para obter mais detalhes",
     "Due date" : "Data limite",
     "Last modified" : "Última modificação",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarefa Concluída","%n Tarefas Concluídas"],
     "Tomorrow" : "Amanhã",
-    "Set start date" : "Defina a data de inicio ",
-    "Set due date" : "Definir data de expiração",
-    "Task not found!" : "Tarefa não encontrada!",
+    "New List" : "Nova Lista",
+    "All day" : "Todo o dia",
     "When shared show full event" : "Quando partilhado, mostrar evento completo",
     "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
     "When shared hide this event" : "Quando partilhado, ocultar este evento",
+    "Task not found!" : "Tarefa não encontrada!",
+    "Set start date" : "Defina a data de inicio ",
+    "Set due date" : "Definir data de expiração",
     "An error occurred" : "Ocorreu um erro"
 },
 "nplurals=2; plural=(n != 1);");
